@@ -11,21 +11,22 @@ import system.date
 from com.inductiveautomation.ignition.common import Dataset
 from java.util import Date
 
-from incendium.helper.types import DictStringAny, String
+from incendium.helper.types import AnyStr, DictStringAny
 
 
 class _NanoXML(object):
-    indent = None  # type: String
-    root = None  # type: String
+    indent = None  # type: AnyStr
+    root = None  # type: AnyStr
 
     def __init__(self, root="root", indent="\t"):
-        # type: (String, String) -> None
+        # type: (AnyStr, AnyStr) -> None
         """Nano XML initializer.
 
         Args:
             root: The value of the XML root element.
             indent: Character(s) used for indentation.
         """
+        super(_NanoXML, self).__init__()
         self.root = root
         self.indent = indent
         self._new_line = "\n"
@@ -34,7 +35,7 @@ class _NanoXML(object):
         )
 
     def add_element(self, name):
-        # type: (String) -> None
+        # type: (AnyStr) -> None
         """Add an element to the XML document.
 
         Args:
@@ -45,7 +46,7 @@ class _NanoXML(object):
         )
 
     def add_sub_element(self, name, value):
-        # type: (String, String) -> None
+        # type: (AnyStr, AnyStr) -> None
         """Add a sub element to an element.
 
         Args:
@@ -60,7 +61,7 @@ class _NanoXML(object):
         )
 
     def close_element(self, name):
-        # type: (String) -> None
+        # type: (AnyStr) -> None
         """Close element.
 
         Args:
@@ -71,7 +72,7 @@ class _NanoXML(object):
         )
 
     def to_string(self):
-        # type: () -> String
+        # type: () -> AnyStr
         """Return the string representation of the XML document.
 
         Returns:
@@ -98,7 +99,7 @@ def _format_object(obj):
 
 
 def _format_value(obj, header=""):
-    # type: (Any, String) -> String
+    # type: (Any, AnyStr) -> AnyStr
     """Format the value to be properly represented in JSON.
 
     Args:
@@ -114,9 +115,7 @@ def _format_value(obj, header=""):
     elif isinstance(obj, basestring):
         _obj = '"{}"'.format(obj)
     elif isinstance(obj, Date):
-        _obj = '"{}"'.format(
-            system.date.format(obj, "yyyy-MM-dd'T'HH:mm:ss.SSSXXX")
-        )
+        _obj = '"{}"'.format(system.date.format(obj, "yyyy-MM-dd'T'HH:mm:ss.SSSXXX"))
     elif isinstance(obj, Dataset):
         _obj = _to_json(obj, header, False)
     else:
@@ -125,7 +124,7 @@ def _format_value(obj, header=""):
 
 
 def _to_json(dataset, root=None, is_root=True):
-    # type: (Dataset, Optional[String], bool) -> String
+    # type: (Dataset, Optional[AnyStr], bool) -> AnyStr
     """Return a string JSON representation of the Dataset.
 
     Private function.
@@ -181,8 +180,7 @@ def _to_jsonobject(dataset):
 
     for i in range(row_count):
         row_dict = {
-            header: _format_object(dataset.getValueAt(i, header))
-            for header in headers
+            header: _format_object(dataset.getValueAt(i, header)) for header in headers
         }
         data.append(row_dict)
 
@@ -190,7 +188,7 @@ def _to_jsonobject(dataset):
 
 
 def to_json(dataset, root=None):
-    # type: (Dataset, Optional[String]) -> String
+    # type: (Dataset, Optional[AnyStr]) -> AnyStr
     """Return a string JSON representation of the Dataset.
 
     Args:
@@ -217,7 +215,7 @@ def to_jsonobject(dataset):
 
 
 def to_xml(dataset, root="root", element="row", indent="\t"):
-    # type: (Dataset, String, String, String) -> String
+    # type: (Dataset, AnyStr, AnyStr, AnyStr) -> AnyStr
     r"""Return a string XML representation of the Dataset.
 
     Args:
