@@ -21,7 +21,7 @@ import system.db
 from com.inductiveautomation.ignition.common import BasicDataset
 from java.lang import Thread
 
-from incendium.helper.types import DictIntStringAny, SProcResult, String
+from incendium.helper.types import AnyStr, DictIntStringAny, SProcResult
 
 
 class DisposableConnection(object):
@@ -32,11 +32,11 @@ class DisposableConnection(object):
     resources.
     """
 
-    database = None  # type: String
+    database = None  # type: AnyStr
     retries = None  # type: int
 
     def __init__(self, database, retries=3):
-        # type: (String, int) -> None
+        # type: (AnyStr, int) -> None
         """Disposable Connection initializer.
 
         Args:
@@ -45,6 +45,7 @@ class DisposableConnection(object):
             retries: The number of additional times to retry
                 enabling the connection. Optional.
         """
+        super(DisposableConnection, self).__init__()
         self.database = database
         self.retries = retries
 
@@ -88,10 +89,10 @@ class DisposableConnection(object):
 
     @property
     def status(self):
-        # type: () -> String
+        # type: () -> AnyStr
         """Get connection status."""
         connection_info = system.db.getConnectionInfo(self.database)
-        return connection_info.getValueAt(0, "Status")
+        return str(connection_info.getValueAt(0, "Status"))
 
 
 class Param(object):
@@ -99,7 +100,7 @@ class Param(object):
 
     def __init__(
         self,
-        name_or_index,  # type: Union[int, String]
+        name_or_index,  # type: Union[int, AnyStr]
         type_code,  # type: int
         value=None,  # type: Optional[Any]
     ):
@@ -111,11 +112,12 @@ class Param(object):
             type_code: Type code constant.
             value: Value of type type_code.
         """
+        super(Param, self).__init__()
         self._name_or_index = name_or_index
         self._type_code = type_code
         self._value = value
 
-    def __repr__(self):
+    def __repr__(self):  # type: ignore[no-untyped-def]
         """Compute the "official" string representation."""
         return "{}(name_or_index={!r}, type_code={}, value={})".format(
             self.__class__.__name__,
@@ -124,15 +126,13 @@ class Param(object):
             self.value,
         )
 
-    def __str__(self):
+    def __str__(self):  # type: ignore[no-untyped-def]
         """Compute the "informal" string representation."""
-        return "{!r}, {}, {}".format(
-            self.name_or_index, self.type_code, self.value
-        )
+        return "{!r}, {}, {}".format(self.name_or_index, self.type_code, self.value)
 
     @property
     def name_or_index(self):
-        # type: () -> Union[int, String]
+        # type: () -> Union[int, AnyStr]
         """Get value of name_or_index."""
         return self._name_or_index
 
@@ -153,7 +153,7 @@ class InParam(Param):
     """Class used for declaring INPUT parameters."""
 
     def __init__(self, name_or_index, type_code, value):
-        # type: (Union[int, String], int, Any) -> None
+        # type: (Union[int, AnyStr], int, Any) -> None
         """Create an instance of InParam.
 
         Args:
@@ -162,16 +162,14 @@ class InParam(Param):
             type_code: Type code constant from `system.db`.
             value: Value of type type_code.
         """
-        super(InParam, self).__init__(
-            name_or_index=name_or_index, type_code=type_code, value=value
-        )
+        super(InParam, self).__init__(name_or_index, type_code, value)
 
 
 class OutParam(Param):
     """Class used for declaring OUTPUT parameters."""
 
     def __init__(self, name_or_index, type_code):
-        # type: (Union[int, String], int) -> None
+        # type: (Union[int, AnyStr], int) -> None
         """Create an instance of OutParam.
 
         Args:
@@ -179,15 +177,13 @@ class OutParam(Param):
                 (str).
             type_code: Type code constant from `system.db`.
         """
-        super(OutParam, self).__init__(
-            name_or_index=name_or_index, type_code=type_code
-        )
+        super(OutParam, self).__init__(name_or_index, type_code)
 
 
 def _execute_sp(
-    stored_procedure,  # type: String
-    database="",  # type: String
-    transaction=None,  # type: Optional[String]
+    stored_procedure,  # type: AnyStr
+    database="",  # type: AnyStr
+    transaction=None,  # type: Optional[AnyStr]
     skip_audit=False,  # type: bool
     in_params=None,  # type: Optional[List[InParam]]
     out_params=None,  # type: Optional[List[OutParam]]
@@ -259,14 +255,14 @@ def _execute_sp(
 
     return {
         "output_params": _out_params,
-        "result_set": call.getResultSet() if get_result_set else None,
+        "result_set": call.getResultSet() if get_result_set else BasicDataset(),
         "return_value": call.getReturnValue() if get_ret_val else None,
         "update_count": call.getUpdateCount() if get_update_count else -1,
     }
 
 
 def check(stored_procedure, database="", params=None):
-    # type: (String, String, Optional[List[InParam]]) -> Optional[bool]
+    # type: (AnyStr, AnyStr, Optional[List[InParam]]) -> Optional[bool]
     """Execute a stored procedure against the connection.
 
     This will return a flag set to TRUE or FALSE.
@@ -286,15 +282,13 @@ def check(stored_procedure, database="", params=None):
         stored_procedure, output=[output], database=database, params=params
     )
 
-    return (
-        output_params["flag"] if "flag" in output_params.iterkeys() else None
-    )
+    return output_params["flag"] if "flag" in output_params.iterkeys() else None
 
 
 def execute_non_query(
-    stored_procedure,  # type: String
-    database="",  # type: String
-    transaction=None,  # type: Optional[String]
+    stored_procedure,  # type: AnyStr
+    database="",  # type: AnyStr
+    transaction=None,  # type: Optional[AnyStr]
     params=None,  # type: Optional[List[InParam]]
 ):
     # type: (...) -> int
@@ -328,11 +322,11 @@ def execute_non_query(
 
 
 def get_data(
-    stored_procedure,  # type: String
-    database="",  # type: String
+    stored_procedure,  # type: AnyStr
+    database="",  # type: AnyStr
     params=None,  # type: Optional[List[InParam]]
 ):
-    # type: (...) -> Optional[BasicDataset]
+    # type: (...) -> BasicDataset
     """Get data by executing a stored procedure.
 
     Args:
@@ -345,7 +339,7 @@ def get_data(
 
     Returns:
         A Dataset that is the resulting data of the stored procedure
-        call, if any.
+        call.
     """
     result = _execute_sp(
         stored_procedure,
@@ -358,10 +352,10 @@ def get_data(
 
 
 def get_output_params(
-    stored_procedure,  # type: String
+    stored_procedure,  # type: AnyStr
     output,  # type: List[OutParam]
-    database="",  # type: String
-    transaction=None,  # type: Optional[String]
+    database="",  # type: AnyStr
+    transaction=None,  # type: Optional[AnyStr]
     params=None,  # type: Optional[List[InParam]]
 ):
     # type: (...) -> DictIntStringAny
@@ -380,7 +374,7 @@ def get_output_params(
             objects. Optional.
 
     Returns:
-        A Python dictionary of OUTPUT paramaters.
+        A Python dictionary of OUTPUT parameters.
     """
     result = _execute_sp(
         stored_procedure,
@@ -395,10 +389,10 @@ def get_output_params(
 
 
 def get_return_value(
-    stored_procedure,  # type: String
+    stored_procedure,  # type: AnyStr
     return_type_code,  # type: int
-    database="",  # type: String
-    transaction=None,  # type: Optional[String]
+    database="",  # type: AnyStr
+    transaction=None,  # type: Optional[AnyStr]
     params=None,  # type: Optional[List[InParam]]
 ):
     # type: (...) -> Optional[int]
@@ -431,10 +425,10 @@ def get_return_value(
 
 
 def o_execute_non_query(
-    stored_procedure,  # type: String
+    stored_procedure,  # type: AnyStr
     out_params,  # type: List[OutParam]
-    database="",  # type: String
-    transaction=None,  # type: Optional[String]
+    database="",  # type: AnyStr
+    transaction=None,  # type: Optional[AnyStr]
     in_params=None,  # type: Optional[List[InParam]]
 ):
     # type: (...) -> Tuple[int, DictIntStringAny]
@@ -473,12 +467,12 @@ def o_execute_non_query(
 
 
 def o_get_data(
-    stored_procedure,  # type: String
+    stored_procedure,  # type: AnyStr
     out_params,  # type: List[OutParam]
-    database="",  # type: String
+    database="",  # type: AnyStr
     in_params=None,  # type: Optional[List[InParam]]
 ):
-    # type: (...) -> Tuple[Optional[BasicDataset], DictIntStringAny]
+    # type: (...) -> Tuple[BasicDataset, DictIntStringAny]
     """Get data by executing a stored procedure and OUTPUT parameters.
 
     Args:
@@ -493,7 +487,7 @@ def o_get_data(
 
     Returns:
         A tuple containing a Dataset that is the resulting data of the
-        stored procedure call, if any, and the OUTPUT parameters.
+        stored procedure call, and the OUTPUT parameters.
     """
     result = _execute_sp(
         stored_procedure,
