@@ -5,6 +5,7 @@ from typing import Any, Dict, Optional, TypedDict, Union
 from com.inductiveautomation.ignition.common import BasicDataset
 from java.lang import Exception as JavaException
 
+AnyStr = Union[str, unicode]
 DictIntStringAny = Dict[Union[int, str, unicode], Any]
 DictStringAny = Dict[Union[str, unicode], Any]
 InnerException = Optional[Union[Exception, JavaException]]
@@ -13,9 +14,8 @@ SProcResult = TypedDict(
     "SProcResult",
     {
         "output_params": DictIntStringAny,
-        "result_set": Optional[BasicDataset],
+        "result_set": BasicDataset,
         "return_value": Optional[int],
         "update_count": int,
     },
 )
-String = Union[str, unicode]
