@@ -16,12 +16,12 @@ import system.util
 from java.util import Date
 
 from incendium import constants
-from incendium.helper.types import Number, String
+from incendium.helper.types import AnyStr, Number
 from incendium.user import IncendiumUser
 
 
 def _format_error_message(counter, error_message, key):
-    # type: (int, String, String) -> String
+    # type: (int, AnyStr, AnyStr) -> AnyStr
     """Format error message.
 
     Args:
@@ -33,15 +33,13 @@ def _format_error_message(counter, error_message, key):
         Formatted error message.
     """
     error_message += (
-        constants.TABBED_LINE + key
-        if counter == 1
-        else constants.NEW_TABBED_LINE + key
+        constants.TABBED_LINE + key if counter == 1 else constants.NEW_TABBED_LINE + key
     )
     return error_message
 
 
 def get_function_name():
-    # type: () -> String
+    # type: () -> AnyStr
     """Get the name of the function last called.
 
     Returns:
@@ -51,7 +49,7 @@ def get_function_name():
 
 
 def get_timer(date):
-    # type: (Union[Date, long]) -> String
+    # type: (Union[Date, long]) -> AnyStr
     """Get a timer with the time elapsed from value until now.
 
     Args:
@@ -67,7 +65,7 @@ def get_timer(date):
 
 
 def get_timestamp(value):
-    # type: (int) -> String
+    # type: (int) -> AnyStr
     """Get timestamp in "hh:mm:ss" format.
 
     Args:
@@ -92,20 +90,18 @@ def set_locale(user):
         user: IncendiumUser instance.
     """
     locale = (
-        user.locale
-        if user is not None and user.locale
-        else constants.DEFAULT_LANGUAGE
+        user.locale if user is not None and user.locale else constants.DEFAULT_LANGUAGE
     )
 
     system.util.setLocale(locale)
 
 
 def validate_form(
-    strings=None,  # type: Optional[Dict[String, String]]
-    numbers=None,  # type: Optional[Dict[String, Number]]
-    collections=None,  # type: Optional[Dict[String, Number]]
+    strings=None,  # type: Optional[Dict[AnyStr, AnyStr]]
+    numbers=None,  # type: Optional[Dict[AnyStr, Number]]
+    collections=None,  # type: Optional[Dict[AnyStr, Number]]
 ):
-    # type: (...) -> Tuple[bool, String]
+    # type: (...) -> Tuple[bool, AnyStr]
     """Perform a form validation.
 
     Args:
@@ -129,9 +125,7 @@ def validate_form(
         for key, str_val in strings.iteritems():
             if not str_val:
                 counter += 1
-                error_message = _format_error_message(
-                    counter, error_message, key
-                )
+                error_message = _format_error_message(counter, error_message, key)
                 is_valid = False
 
     merged_dict = {}
@@ -144,9 +138,7 @@ def validate_form(
         for key, num_val in merged_dict.iteritems():
             if num_val is None or num_val <= 0:
                 counter += 1
-                error_message = _format_error_message(
-                    counter, error_message, key
-                )
+                error_message = _format_error_message(counter, error_message, key)
                 is_valid = False
 
     return is_valid, error_message
